<?php

namespace App\Controllers;

class AppBuilder extends BaseController
{
    public function index()
    {
        // Path to the modules directory
        $modulesPath = APPPATH . 'Views/modules/';

        // Get all module files
        $modules = [];
        if (is_dir($modulesPath)) {
            $files = scandir($modulesPath);
            foreach ($files as $file) {
                if (pathinfo($file, PATHINFO_EXTENSION) === 'php') {
                    $filePath = $modulesPath . $file;
                    
                    // Extract module name from file
                    $moduleName = $this->extractModuleName($filePath);
                    
                    $modules[] = [
                        'name' => $moduleName,
                        'file' => $file
                    ];
                }
            }
        }

        // Pass modules list to the view
        return view('app_builder', ['modules' => $modules]);
    }

    /**
     * Extracts the Module Name from the PHP comment block at the top of the file.
     * Falls back to a cleaned filename if no module name is found.
     */
    private function extractModuleName($filePath)
    {
        $content = file_get_contents($filePath);
        preg_match('/Module Name:\s*(.+)/', $content, $matches);
        
        if (!empty($matches[1])) {
            return trim($matches[1]);
        }

        // Fallback: Format filename as a title (e.g., "title_page" → "Title Page")
        return ucfirst(str_replace('_', ' ', pathinfo($filePath, PATHINFO_FILENAME)));
    }
}
